@@ -6,7 +6,9 @@
 #include <libexif/exif-data.h>
 #endif
 #include "eog-image.h"
-
+#if HAVE_LCMS
+#include <lcms.h>
+#endif
 
 typedef enum {
 	EOG_IMAGE_STATUS_UNKNOWN,
@@ -25,6 +27,8 @@ struct _EogImagePrivate {
 	gint width;
 	gint height;
 	GnomeVFSFileSize bytes;
+	GnomeVFSMonitorHandle *monitor_handle;
+	gpointer toclean;
 	char *file_type;
 
 	guchar  *exif_chunk; /* holds EXIF raw data */
@@ -36,7 +40,10 @@ struct _EogImagePrivate {
 			      * either of these are not NULL:
 			      */
 #endif
-	
+#if HAVE_LCMS
+	cmsHPROFILE profile;
+#endif
+
 	gint thumbnail_id;
 	
 	gboolean modified;
