@@ -4,11 +4,16 @@
 #include <glib-object.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-file-size.h>
+#include <libgnomeprint/gnome-print.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include "eog-transform.h"
 #include "eog-image-save-info.h"
 #include "eog-job.h"
 
+#if HAVE_LCMS
+#include <lcms.h>
+#endif
+
 G_BEGIN_DECLS
 
 #define EOG_TYPE_IMAGE          (eog_image_get_type ())
@@ -115,10 +120,22 @@ GnomeVFSURI*        eog_image_get_uri                         (EogImage *img);
 gchar*              eog_image_get_uri_for_display             (EogImage *img);
 gboolean            eog_image_has_metadata                    (EogImage *img);
 
+#if HAVE_LCMS
+cmsHPROFILE eog_image_get_profile (EogImage *img);
+void eog_image_apply_display_profile (EogImage *img, cmsHPROFILE profile);
+#endif
+
 /* modification API */
 void                eog_image_transform                       (EogImage *img, EogTransform *trans, EogJob *job);
 void                eog_image_undo                            (EogImage *img);
 
+
+/* print API */
+void               eog_image_print                            (EogImage *img, GnomePrintContext *pc, gdouble width, gdouble height);
+
+/* Register API */
+void               eog_image_register_infoview                (EogImage *img, gpointer view);
+
 G_END_DECLS
 
 #endif /* _IMAGE_H_ */
